//
//  QueriesTableViewController.m
//  Busca Pios
//
//  Created by Santiago Pavón on 16/11/13.
//  Copyright (c) 2013 UPM. All rights reserved.
//

#import "CitiesTableViewController.h"
#import "CityEditorViewController.h"
#import "CityWeatherViewController.h"

#define QUERIES_FILENAME @"cities.plist"

@interface CitiesTableViewController ()

@property (strong) NSMutableArray * cities;

@end

@implementation CitiesTableViewController


- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    self.navigationItem.leftBarButtonItem = self.editButtonItem;
    
    [self loadCities];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.cities count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"City Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier
                                                            forIndexPath:indexPath];
    
    cell.textLabel.text = self.cities[indexPath.row];

    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section {
    
    return @"Selecciona una Ciudad";
}

- (NSString *)tableView:(UITableView *)tableView titleForFooterInSection:(NSInteger)section {
    
    return @"IWEB 2013/2014 Práctica 11";
}


/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/


// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [self.cities removeObjectAtIndex:indexPath.row];

        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];

        [self saveQueries];
    }
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}



// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{

    id obj = self.cities[fromIndexPath.row];
    
    [self.cities removeObjectAtIndex:fromIndexPath.row];
    [self.cities insertObject:obj atIndex:toIndexPath.row];
    
    [self saveQueries];
}



// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}


#pragma mark - Table view delegate


- (NSString *)tableView:(UITableView *)tableView titleForDeleteConfirmationButtonForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    return @"ñam ñam";
}

/*
#pragma mark - Navigation

// In a story board-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}

 */


#pragma mark - Segues

- (void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    
    NSLog(@"%@",segue.identifier);
    
    if ([segue.identifier isEqualToString:@"Show City"]) {
       
        CityWeatherViewController * cwvc = segue.destinationViewController;
        
        NSInteger row = [self.tableView indexPathForSelectedRow].row;
        
        cwvc.city = self.cities[row];
        
        
    } else if ([segue.identifier isEqualToString:@"Add City"]) {
        
        [self.cities insertObject:@"" atIndex:0];
        
        
        NSIndexPath *indexPath = [NSIndexPath indexPathForRow:0 inSection:0];
        
        [self.tableView insertRowsAtIndexPaths:@[indexPath]
                              withRowAnimation:UITableViewRowAnimationAutomatic];
        
        [self.tableView scrollToRowAtIndexPath:indexPath
                              atScrollPosition:UITableViewScrollPositionTop
                                      animated:YES];
        
        
        CityEditorViewController *qevc = (CityEditorViewController*)segue.destinationViewController;
        
        qevc.city = @"";
        qevc.row = 0;
        
    } else if ([segue.identifier isEqualToString:@"Edit City"]) {
        
        NSIndexPath * indexPath = [self.tableView indexPathForCell:sender];
        
        CityEditorViewController *qevc = (CityEditorViewController*)segue.destinationViewController;
        
        qevc.city = self.cities[indexPath.row];
        qevc.row = indexPath.row;
    }
    
}


- (IBAction) queryWasEdited:(UIStoryboardSegue*)segue
{
    CityEditorViewController *qevc = (CityEditorViewController*)segue.sourceViewController;
    
    if (qevc.city) { // La edicion no fue cancelada
        
        NSIndexPath *ip = [NSIndexPath indexPathForRow:qevc.row inSection:0];
        
        NSString * query = [qevc.city stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceCharacterSet]];
        
        if ([query isEqualToString:@""]) { // Borro la query
            [self.cities removeObjectAtIndex:ip.row];
            
            [self.tableView deleteRowsAtIndexPaths:@[ip]
                                  withRowAnimation:UITableViewRowAnimationLeft];
            
        } else { // Actualizo la query
            [self.cities replaceObjectAtIndex:ip.row withObject:query];
            
            
            [self.tableView reloadRowsAtIndexPaths:@[ip]
                                  withRowAnimation:UITableViewRowAnimationLeft];
        }
        
        [self saveQueries];
    }
}


#pragma mark - Persistence

- (NSString*) getQueriesPath {
    
    NSString * docsDir = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory,NSUserDomainMask,YES)[0];
    
    return [docsDir stringByAppendingPathComponent:QUERIES_FILENAME];
}


- (void) loadCities {
    
    self.cities = [NSMutableArray arrayWithContentsOfFile:[self getQueriesPath]];
    
    if ( ! self.cities) {
        self.cities = [NSMutableArray  arrayWithArray:@[@"Madrid",
                                                         @"Paris",
                                                         @"Lisboa",
                                                         @"Londres",
                                                         @"Moscu",
                                                         @"Caracas",
                                                         @"Tripoli",
                                                         @"Tokio"]];
    }
}

- (void) saveQueries {
    
    [self.cities writeToFile:[self getQueriesPath] atomically:YES];
}
@end
