//
//  CityWeatherViewController.m
//  El Vuelo del Grajo
//
//  Created by Santiago Pavón on 28/11/13.
//  Copyright (c) 2013 UPM. All rights reserved.
//

#import "CityWeatherViewController.h"

#import "MapKit/MapKit.h"

#define OPE_W_URL @"http://api.openweathermap.org/data/2.5/weather"


@interface CityWeatherViewController ()

@property (weak, nonatomic) IBOutlet UITableViewCell *temperatureCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *temperatureMaxCell;

@property (weak, nonatomic) IBOutlet UITableViewCell *temperatureMinCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *humidityCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *pressureCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *sunriseCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *sunsetCell;
@property (weak, nonatomic) IBOutlet UITableViewCell *weatherCell;
@property (weak, nonatomic) IBOutlet MKMapView *mapView;

@end

@implementation CityWeatherViewController



- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
    
    self.title = self.city;
    
    [self downloadWeather];
}


- (void) downloadWeather
{
    
    // Construimos la URL añadiendo la query
    NSString * s = [NSString stringWithFormat:@"%@?q=%@&units=metric&lang=sp",OPE_W_URL,self.city];
    
    s = [s stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    
    NSURL *url = [NSURL URLWithString:s];
    
    NSData *data = [NSData dataWithContentsOfURL:url];
    
    if (! data) {
        NSLog(@"Error: no se han descargado datos.");
        return;
    }
    
    NSDictionary * dic;
    NSError * err;
    dic = [NSJSONSerialization JSONObjectWithData:data
                                          options:NSJSONReadingMutableContainers
                                            error:&err];
    if (!dic) {
        NSLog(@"Error parsing JSON = %@",[err localizedDescription]);
        return;
    }
    
    
    // Log main keys
    for (NSString *key in [dic allKeys]) {
        NSLog(@"KEY = %@ -> %@",key, dic[key]);
    }
    
    NSNumber * ntemp = dic[@"main"][@"temp"];
    self.temperatureCell.detailTextLabel.text = [NSString stringWithFormat:@"%d ºC",ntemp.intValue];

    ntemp = dic[@"main"][@"temp_max"];
    self.temperatureMaxCell.detailTextLabel.text = [NSString stringWithFormat:@"%d ºC",ntemp.intValue];
    
    ntemp = dic[@"main"][@"temp_min"];
    self.temperatureMinCell.detailTextLabel.text = [NSString stringWithFormat:@"%d ºC",ntemp.intValue];
    
    NSNumber * nhumd = dic[@"main"][@"humidity"];
    self.humidityCell.detailTextLabel.text = [NSString stringWithFormat:@"%d %%",nhumd.intValue];
    
    NSNumber * npress = dic[@"main"][@"pressure"];
    self.pressureCell.detailTextLabel.text = [NSString stringWithFormat:@"%d P",npress.intValue];
    
    
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"HH:mm"];

    NSNumber * ndate = dic[@"sys"][@"sunrise"];
    NSDate * date = [[NSDate alloc] initWithTimeIntervalSince1970:ndate.doubleValue];
    
    self.sunriseCell.detailTextLabel.text = [NSString stringWithFormat:@"%@",[dateFormatter stringFromDate:date]];

    ndate = dic[@"sys"][@"sunset"];
    date = [[NSDate alloc] initWithTimeIntervalSince1970:ndate.doubleValue];
                                             
    self.sunsetCell.detailTextLabel.text = [NSString stringWithFormat:@"%@",[dateFormatter stringFromDate:date]];

    self.weatherCell.textLabel.text = dic[@"weather"][0][@"description"];
    
    NSNumber * nlatitude = dic[@"coord"][@"lat"];
    NSNumber * nlongitude =  dic[@"coord"][@"lon"];
    
    MKCoordinateRegion reg;
    reg.center.latitude = nlatitude.floatValue;
        reg.center.longitude = nlongitude.floatValue;
    reg.span.latitudeDelta = 0.5;
    reg.span.longitudeDelta = 0.5;
	[self.mapView setRegion:reg animated:NO];
    self.mapView.mapType = MKMapTypeHybrid;
    self.mapView.userInteractionEnabled = NO;

}


@end
